@@ -175,7 +175,7 @@ get_shades <- function(offsets,dat,ntop=ntop,include_chrX=FALSE,ymin=NULL,ymax=N
   }
   ##### here we need to account for whether we have chr X or not
   if(include_chrX){
-    shades <- data.frame(x1=c(offsets[[2]],offsets[[4]],offsets[[6]],offsets[[8]],offsets[[10]],offsets[[12]],offsets[[14]],offsets[[16]],offsets[[18]],offsets[[20]],offsets[[22]]),
+      shades <- data.frame(x1=c(offsets[[2]],offsets[[4]],offsets[[6]],offsets[[8]],offsets[[10]],offsets[[12]],offsets[[14]],offsets[[16]],offsets[[18]],offsets[[20]],offsets[[22]]),
                       x2=c(offsets[[3]],offsets[[5]],offsets[[7]], offsets[[9]],offsets[[11]],offsets[[13]],offsets[[15]],offsets[[17]],offsets[[19]],offsets[[21]],offsets[[23]]),
                       y1=y1,
                       y2=c(rep(ymax, n_offsets)))
@@ -186,7 +186,6 @@ get_shades <- function(offsets,dat,ntop=ntop,include_chrX=FALSE,ymin=NULL,ymax=N
                       y1=y1,
                       y2=c(rep(ymax, n_offsets)))
   }
-
   return(shades)
 }
 
@@ -226,11 +225,9 @@ get_chr_lengths_and_offsets <- function(include_chrX=F){
   chr_lengths[chr_lengths$CHROM=="X",'CHROM'] <- "23"
   chr_lengths[chr_lengths$CHROM=="Y",'CHROM'] <- "24"
   chr_lengths$CHROM <- as.integer(chr_lengths$CHROM)
-  no_chrs <- 22
-  if(include_chrX)
-    no_chrs <- 23
+  no_chrs <-ifelse(include_chrX, 23,22)
   chr_lengths <- chr_lengths %>% dplyr::filter(CHROM< no_chrs +1 )
- chr_lengths_and_offsets <- chr_lengths %>% dplyr::group_by(CHROM) %>% dplyr::summarize(m=V2) %>% dplyr::mutate(offset=cumsum(as.numeric(lag(m, default=0))))
+  chr_lengths_and_offsets <- chr_lengths %>% dplyr::group_by(CHROM) %>% dplyr::summarize(m=V2) %>% dplyr::mutate(offset=cumsum(as.numeric(lag(m, default=0))))
   return(chr_lengths_and_offsets)
 }
 
